# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Network']


class Network(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attachable: Optional[pulumi.Input[bool]] = None,
                 check_duplicate: Optional[pulumi.Input[bool]] = None,
                 driver: Optional[pulumi.Input[str]] = None,
                 ingress: Optional[pulumi.Input[bool]] = None,
                 internal: Optional[pulumi.Input[bool]] = None,
                 ipam_configs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkIpamConfigArgs']]]]] = None,
                 ipam_driver: Optional[pulumi.Input[str]] = None,
                 ipv6: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLabelArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Manages a Docker Network. This can be used alongside
        [docker\_container](https://www.terraform.io/docs/providers/docker/r/container.html)
        to create virtual networks within the docker environment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        # Create a new docker network
        private_network = docker.Network("privateNetwork")
        ```

        ## Import

        Docker networks can be imported using the long id, e.g. for a network with the short id `p73jelnrme5f`

        ```sh
         $ pulumi import docker:index/network:Network foo $(docker network inspect -f {{.ID}} p73)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] attachable: Enable manual container attachment to the network.
               Defaults to `false`.
        :param pulumi.Input[bool] check_duplicate: Requests daemon to check for networks
               with same name.
        :param pulumi.Input[str] driver: Name of the network driver to use. Defaults to
               `bridge` driver.
        :param pulumi.Input[bool] ingress: Create swarm routing-mesh network.
               Defaults to `false`.
        :param pulumi.Input[bool] internal: Restrict external access to the network.
               Defaults to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkIpamConfigArgs']]]] ipam_configs: See IPAM config below for
               details.
        :param pulumi.Input[str] ipam_driver: Driver used by the custom IP scheme of the
               network.
        :param pulumi.Input[bool] ipv6: Enable IPv6 networking.
               Defaults to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLabelArgs']]]] labels: See Labels below for details.
        :param pulumi.Input[str] name: The name of the Docker network.
        :param pulumi.Input[Mapping[str, Any]] options: Network specific options to be used by
               the drivers.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['attachable'] = attachable
            __props__['check_duplicate'] = check_duplicate
            __props__['driver'] = driver
            __props__['ingress'] = ingress
            __props__['internal'] = internal
            __props__['ipam_configs'] = ipam_configs
            __props__['ipam_driver'] = ipam_driver
            __props__['ipv6'] = ipv6
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['options'] = options
            __props__['scope'] = None
        super(Network, __self__).__init__(
            'docker:index/network:Network',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attachable: Optional[pulumi.Input[bool]] = None,
            check_duplicate: Optional[pulumi.Input[bool]] = None,
            driver: Optional[pulumi.Input[str]] = None,
            ingress: Optional[pulumi.Input[bool]] = None,
            internal: Optional[pulumi.Input[bool]] = None,
            ipam_configs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkIpamConfigArgs']]]]] = None,
            ipam_driver: Optional[pulumi.Input[str]] = None,
            ipv6: Optional[pulumi.Input[bool]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLabelArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            options: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            scope: Optional[pulumi.Input[str]] = None) -> 'Network':
        """
        Get an existing Network resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] attachable: Enable manual container attachment to the network.
               Defaults to `false`.
        :param pulumi.Input[bool] check_duplicate: Requests daemon to check for networks
               with same name.
        :param pulumi.Input[str] driver: Name of the network driver to use. Defaults to
               `bridge` driver.
        :param pulumi.Input[bool] ingress: Create swarm routing-mesh network.
               Defaults to `false`.
        :param pulumi.Input[bool] internal: Restrict external access to the network.
               Defaults to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkIpamConfigArgs']]]] ipam_configs: See IPAM config below for
               details.
        :param pulumi.Input[str] ipam_driver: Driver used by the custom IP scheme of the
               network.
        :param pulumi.Input[bool] ipv6: Enable IPv6 networking.
               Defaults to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLabelArgs']]]] labels: See Labels below for details.
        :param pulumi.Input[str] name: The name of the Docker network.
        :param pulumi.Input[Mapping[str, Any]] options: Network specific options to be used by
               the drivers.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["attachable"] = attachable
        __props__["check_duplicate"] = check_duplicate
        __props__["driver"] = driver
        __props__["ingress"] = ingress
        __props__["internal"] = internal
        __props__["ipam_configs"] = ipam_configs
        __props__["ipam_driver"] = ipam_driver
        __props__["ipv6"] = ipv6
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["options"] = options
        __props__["scope"] = scope
        return Network(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def attachable(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable manual container attachment to the network.
        Defaults to `false`.
        """
        return pulumi.get(self, "attachable")

    @property
    @pulumi.getter(name="checkDuplicate")
    def check_duplicate(self) -> pulumi.Output[Optional[bool]]:
        """
        Requests daemon to check for networks
        with same name.
        """
        return pulumi.get(self, "check_duplicate")

    @property
    @pulumi.getter
    def driver(self) -> pulumi.Output[str]:
        """
        Name of the network driver to use. Defaults to
        `bridge` driver.
        """
        return pulumi.get(self, "driver")

    @property
    @pulumi.getter
    def ingress(self) -> pulumi.Output[Optional[bool]]:
        """
        Create swarm routing-mesh network.
        Defaults to `false`.
        """
        return pulumi.get(self, "ingress")

    @property
    @pulumi.getter
    def internal(self) -> pulumi.Output[bool]:
        """
        Restrict external access to the network.
        Defaults to `false`.
        """
        return pulumi.get(self, "internal")

    @property
    @pulumi.getter(name="ipamConfigs")
    def ipam_configs(self) -> pulumi.Output[Sequence['outputs.NetworkIpamConfig']]:
        """
        See IPAM config below for
        details.
        """
        return pulumi.get(self, "ipam_configs")

    @property
    @pulumi.getter(name="ipamDriver")
    def ipam_driver(self) -> pulumi.Output[Optional[str]]:
        """
        Driver used by the custom IP scheme of the
        network.
        """
        return pulumi.get(self, "ipam_driver")

    @property
    @pulumi.getter
    def ipv6(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable IPv6 networking.
        Defaults to `false`.
        """
        return pulumi.get(self, "ipv6")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.NetworkLabel']]]:
        """
        See Labels below for details.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Docker network.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Network specific options to be used by
        the drivers.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Output[str]:
        return pulumi.get(self, "scope")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables
from . import outputs

__all__ = [
    'ca_material',
    'cert_material',
    'cert_path',
    'host',
    'key_material',
    'registry_auth',
]

__config__ = pulumi.Config('docker')

ca_material = __config__.get('caMaterial')
"""
PEM-encoded content of Docker host CA certificate
"""

cert_material = __config__.get('certMaterial')
"""
PEM-encoded content of Docker client certificate
"""

cert_path = __config__.get('certPath')
"""
Path to directory with Docker TLS config
"""

host = __config__.get('host') or (_utilities.get_env('DOCKER_HOST') or 'unix:///var/run/docker.sock')
"""
The Docker daemon address
"""

key_material = __config__.get('keyMaterial')
"""
PEM-encoded content of Docker client private key
"""

registry_auth = __config__.get('registryAuth')




# Copyright 2016-2020, Pulumi Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import typing


def get_image_name_and_tag(base_image_name: str) -> typing.Tuple[str, typing.Optional[str]]:
    # From https://docs.docker.com/engine/reference/commandline/tag
    #
    # "A tag name must be valid ASCII and may contain lowercase and uppercase letters, digits,
    # underscores, periods and dashes. A tag name may not start with a period or a dash and may
    # contain a maximum of 128 characters."
    #
    # So it is safe for us to just look for the colon, and consume whatever follows as the tag
    # for the image.

    try:
        last_colon = base_image_name.index(":")
        return base_image_name[0: last_colon], base_image_name[last_colon + 1:]
    except ValueError:
        return base_image_name, None



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'RegistryAuth',
]

@pulumi.output_type
class RegistryAuth(dict):
    def __init__(__self__, *,
                 address: str,
                 config_file: Optional[str] = None,
                 config_file_content: Optional[str] = None,
                 password: Optional[str] = None,
                 username: Optional[str] = None):
        pulumi.set(__self__, "address", address)
        if config_file is not None:
            pulumi.set(__self__, "config_file", config_file)
        if config_file_content is not None:
            pulumi.set(__self__, "config_file_content", config_file_content)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def address(self) -> str:
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="configFile")
    def config_file(self) -> Optional[str]:
        return pulumi.get(self, "config_file")

    @property
    @pulumi.getter(name="configFileContent")
    def config_file_content(self) -> Optional[str]:
        return pulumi.get(self, "config_file_content")

    @property
    @pulumi.getter
    def password(self) -> Optional[str]:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> Optional[str]:
        return pulumi.get(self, "username")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Service']


class Service(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth: Optional[pulumi.Input[pulumi.InputType['ServiceAuthArgs']]] = None,
                 converge_config: Optional[pulumi.Input[pulumi.InputType['ServiceConvergeConfigArgs']]] = None,
                 endpoint_spec: Optional[pulumi.Input[pulumi.InputType['ServiceEndpointSpecArgs']]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceLabelArgs']]]]] = None,
                 mode: Optional[pulumi.Input[pulumi.InputType['ServiceModeArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 rollback_config: Optional[pulumi.Input[pulumi.InputType['ServiceRollbackConfigArgs']]] = None,
                 task_spec: Optional[pulumi.Input[pulumi.InputType['ServiceTaskSpecArgs']]] = None,
                 update_config: Optional[pulumi.Input[pulumi.InputType['ServiceUpdateConfigArgs']]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        ## Import

        Docker service can be imported using the long id, e.g. for a service with the short id `55ba873dd`

        ```sh
         $ pulumi import docker:index/service:Service foo $(docker service inspect -f {{.ID}} 55b)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ServiceAuthArgs']] auth: See Auth below for details.
        :param pulumi.Input[pulumi.InputType['ServiceConvergeConfigArgs']] converge_config: See Converge Config below for details.
        :param pulumi.Input[pulumi.InputType['ServiceEndpointSpecArgs']] endpoint_spec: See EndpointSpec below for details.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceLabelArgs']]]] labels: See Labels below for details.
        :param pulumi.Input[pulumi.InputType['ServiceModeArgs']] mode: See Mode below for details.
        :param pulumi.Input[str] name: The name of the Docker service.
        :param pulumi.Input[pulumi.InputType['ServiceRollbackConfigArgs']] rollback_config: See RollbackConfig below for details.
        :param pulumi.Input[pulumi.InputType['ServiceTaskSpecArgs']] task_spec: See TaskSpec below for details.
        :param pulumi.Input[pulumi.InputType['ServiceUpdateConfigArgs']] update_config: See UpdateConfig below for details.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auth'] = auth
            __props__['converge_config'] = converge_config
            __props__['endpoint_spec'] = endpoint_spec
            __props__['labels'] = labels
            __props__['mode'] = mode
            __props__['name'] = name
            __props__['rollback_config'] = rollback_config
            if task_spec is None and not opts.urn:
                raise TypeError("Missing required property 'task_spec'")
            __props__['task_spec'] = task_spec
            __props__['update_config'] = update_config
        super(Service, __self__).__init__(
            'docker:index/service:Service',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth: Optional[pulumi.Input[pulumi.InputType['ServiceAuthArgs']]] = None,
            converge_config: Optional[pulumi.Input[pulumi.InputType['ServiceConvergeConfigArgs']]] = None,
            endpoint_spec: Optional[pulumi.Input[pulumi.InputType['ServiceEndpointSpecArgs']]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceLabelArgs']]]]] = None,
            mode: Optional[pulumi.Input[pulumi.InputType['ServiceModeArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            rollback_config: Optional[pulumi.Input[pulumi.InputType['ServiceRollbackConfigArgs']]] = None,
            task_spec: Optional[pulumi.Input[pulumi.InputType['ServiceTaskSpecArgs']]] = None,
            update_config: Optional[pulumi.Input[pulumi.InputType['ServiceUpdateConfigArgs']]] = None) -> 'Service':
        """
        Get an existing Service resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ServiceAuthArgs']] auth: See Auth below for details.
        :param pulumi.Input[pulumi.InputType['ServiceConvergeConfigArgs']] converge_config: See Converge Config below for details.
        :param pulumi.Input[pulumi.InputType['ServiceEndpointSpecArgs']] endpoint_spec: See EndpointSpec below for details.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceLabelArgs']]]] labels: See Labels below for details.
        :param pulumi.Input[pulumi.InputType['ServiceModeArgs']] mode: See Mode below for details.
        :param pulumi.Input[str] name: The name of the Docker service.
        :param pulumi.Input[pulumi.InputType['ServiceRollbackConfigArgs']] rollback_config: See RollbackConfig below for details.
        :param pulumi.Input[pulumi.InputType['ServiceTaskSpecArgs']] task_spec: See TaskSpec below for details.
        :param pulumi.Input[pulumi.InputType['ServiceUpdateConfigArgs']] update_config: See UpdateConfig below for details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auth"] = auth
        __props__["converge_config"] = converge_config
        __props__["endpoint_spec"] = endpoint_spec
        __props__["labels"] = labels
        __props__["mode"] = mode
        __props__["name"] = name
        __props__["rollback_config"] = rollback_config
        __props__["task_spec"] = task_spec
        __props__["update_config"] = update_config
        return Service(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def auth(self) -> pulumi.Output[Optional['outputs.ServiceAuth']]:
        """
        See Auth below for details.
        """
        return pulumi.get(self, "auth")

    @property
    @pulumi.getter(name="convergeConfig")
    def converge_config(self) -> pulumi.Output[Optional['outputs.ServiceConvergeConfig']]:
        """
        See Converge Config below for details.
        """
        return pulumi.get(self, "converge_config")

    @property
    @pulumi.getter(name="endpointSpec")
    def endpoint_spec(self) -> pulumi.Output['outputs.ServiceEndpointSpec']:
        """
        See EndpointSpec below for details.
        """
        return pulumi.get(self, "endpoint_spec")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Sequence['outputs.ServiceLabel']]:
        """
        See Labels below for details.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Output['outputs.ServiceMode']:
        """
        See Mode below for details.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Docker service.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rollbackConfig")
    def rollback_config(self) -> pulumi.Output[Optional['outputs.ServiceRollbackConfig']]:
        """
        See RollbackConfig below for details.
        """
        return pulumi.get(self, "rollback_config")

    @property
    @pulumi.getter(name="taskSpec")
    def task_spec(self) -> pulumi.Output['outputs.ServiceTaskSpec']:
        """
        See TaskSpec below for details.
        """
        return pulumi.get(self, "task_spec")

    @property
    @pulumi.getter(name="updateConfig")
    def update_config(self) -> pulumi.Output[Optional['outputs.ServiceUpdateConfig']]:
        """
        See UpdateConfig below for details.
        """
        return pulumi.get(self, "update_config")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['RegistryImage']


class RegistryImage(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 build: Optional[pulumi.Input[pulumi.InputType['RegistryImageBuildArgs']]] = None,
                 keep_remotely: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides an image/tag in a Docker registry.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        helloworld = docker.RegistryImage("helloworld", build=docker.RegistryImageBuildArgs(
            context="pathToContextFolder",
        ))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['RegistryImageBuildArgs']] build: See Build below for details.
        :param pulumi.Input[bool] keep_remotely: If true, then the Docker image won't be
               deleted on destroy operation. If this is false, it will delete the image from
               the docker registry on destroy operation.
        :param pulumi.Input[str] name: type of ulimit, e.g. nofile
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['build'] = build
            __props__['keep_remotely'] = keep_remotely
            __props__['name'] = name
            __props__['sha256_digest'] = None
        super(RegistryImage, __self__).__init__(
            'docker:index/registryImage:RegistryImage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            build: Optional[pulumi.Input[pulumi.InputType['RegistryImageBuildArgs']]] = None,
            keep_remotely: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            sha256_digest: Optional[pulumi.Input[str]] = None) -> 'RegistryImage':
        """
        Get an existing RegistryImage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['RegistryImageBuildArgs']] build: See Build below for details.
        :param pulumi.Input[bool] keep_remotely: If true, then the Docker image won't be
               deleted on destroy operation. If this is false, it will delete the image from
               the docker registry on destroy operation.
        :param pulumi.Input[str] name: type of ulimit, e.g. nofile
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["build"] = build
        __props__["keep_remotely"] = keep_remotely
        __props__["name"] = name
        __props__["sha256_digest"] = sha256_digest
        return RegistryImage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def build(self) -> pulumi.Output[Optional['outputs.RegistryImageBuild']]:
        """
        See Build below for details.
        """
        return pulumi.get(self, "build")

    @property
    @pulumi.getter(name="keepRemotely")
    def keep_remotely(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the Docker image won't be
        deleted on destroy operation. If this is false, it will delete the image from
        the docker registry on destroy operation.
        """
        return pulumi.get(self, "keep_remotely")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        type of ulimit, e.g. nofile
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="sha256Digest")
    def sha256_digest(self) -> pulumi.Output[str]:
        return pulumi.get(self, "sha256_digest")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['RemoteImage']


class RemoteImage(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 build: Optional[pulumi.Input[pulumi.InputType['RemoteImageBuildArgs']]] = None,
                 force_remove: Optional[pulumi.Input[bool]] = None,
                 keep_locally: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 pull_trigger: Optional[pulumi.Input[str]] = None,
                 pull_triggers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Pulls a Docker image to a given Docker host from a Docker Registry.

        This resource will *not* pull new layers of the image automatically unless used in
        conjunction with [`RegistryImage`](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
        data source to update the `pull_triggers` field.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        # Find the latest Ubuntu precise image.
        ubuntu = docker.RemoteImage("ubuntu", name="ubuntu:precise")
        ```
        ### Dynamic image

        ```python
        import pulumi
        import pulumi_docker as docker

        ubuntu_registry_image = docker.get_registry_image(name="ubuntu:precise")
        ubuntu_remote_image = docker.RemoteImage("ubuntuRemoteImage",
            name=ubuntu_registry_image.name,
            pull_triggers=[ubuntu_registry_image.sha256_digest])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['RemoteImageBuildArgs']] build: See Build below for details.
        :param pulumi.Input[bool] force_remove: Force remove the image when the resource is destroyed
        :param pulumi.Input[bool] keep_locally: If true, then the Docker image won't be
               deleted on destroy operation. If this is false, it will delete the image from
               the docker local storage on destroy operation.
        :param pulumi.Input[str] name: The name of the Docker image, including any tags or SHA256 repo digests.
        :param pulumi.Input[str] pull_trigger: **Deprecated**, use `pull_triggers` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pull_triggers: List of values which cause an
               image pull when changed. This is used to store the image digest from the
               registry when using the `RegistryImage` [data source](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
               to trigger an image update.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['build'] = build
            __props__['force_remove'] = force_remove
            __props__['keep_locally'] = keep_locally
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            if pull_trigger is not None and not opts.urn:
                warnings.warn("""Use field pull_triggers instead""", DeprecationWarning)
                pulumi.log.warn("pull_trigger is deprecated: Use field pull_triggers instead")
            __props__['pull_trigger'] = pull_trigger
            __props__['pull_triggers'] = pull_triggers
            __props__['latest'] = None
            __props__['output'] = None
        super(RemoteImage, __self__).__init__(
            'docker:index/remoteImage:RemoteImage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            build: Optional[pulumi.Input[pulumi.InputType['RemoteImageBuildArgs']]] = None,
            force_remove: Optional[pulumi.Input[bool]] = None,
            keep_locally: Optional[pulumi.Input[bool]] = None,
            latest: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            output: Optional[pulumi.Input[str]] = None,
            pull_trigger: Optional[pulumi.Input[str]] = None,
            pull_triggers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'RemoteImage':
        """
        Get an existing RemoteImage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['RemoteImageBuildArgs']] build: See Build below for details.
        :param pulumi.Input[bool] force_remove: Force remove the image when the resource is destroyed
        :param pulumi.Input[bool] keep_locally: If true, then the Docker image won't be
               deleted on destroy operation. If this is false, it will delete the image from
               the docker local storage on destroy operation.
        :param pulumi.Input[str] name: The name of the Docker image, including any tags or SHA256 repo digests.
        :param pulumi.Input[str] pull_trigger: **Deprecated**, use `pull_triggers` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pull_triggers: List of values which cause an
               image pull when changed. This is used to store the image digest from the
               registry when using the `RegistryImage` [data source](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
               to trigger an image update.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["build"] = build
        __props__["force_remove"] = force_remove
        __props__["keep_locally"] = keep_locally
        __props__["latest"] = latest
        __props__["name"] = name
        __props__["output"] = output
        __props__["pull_trigger"] = pull_trigger
        __props__["pull_triggers"] = pull_triggers
        return RemoteImage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def build(self) -> pulumi.Output[Optional['outputs.RemoteImageBuild']]:
        """
        See Build below for details.
        """
        return pulumi.get(self, "build")

    @property
    @pulumi.getter(name="forceRemove")
    def force_remove(self) -> pulumi.Output[Optional[bool]]:
        """
        Force remove the image when the resource is destroyed
        """
        return pulumi.get(self, "force_remove")

    @property
    @pulumi.getter(name="keepLocally")
    def keep_locally(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the Docker image won't be
        deleted on destroy operation. If this is false, it will delete the image from
        the docker local storage on destroy operation.
        """
        return pulumi.get(self, "keep_locally")

    @property
    @pulumi.getter
    def latest(self) -> pulumi.Output[str]:
        return pulumi.get(self, "latest")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Docker image, including any tags or SHA256 repo digests.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def output(self) -> pulumi.Output[str]:
        return pulumi.get(self, "output")

    @property
    @pulumi.getter(name="pullTrigger")
    def pull_trigger(self) -> pulumi.Output[Optional[str]]:
        """
        **Deprecated**, use `pull_triggers` instead.
        """
        return pulumi.get(self, "pull_trigger")

    @property
    @pulumi.getter(name="pullTriggers")
    def pull_triggers(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of values which cause an
        image pull when changed. This is used to store the image digest from the
        registry when using the `RegistryImage` [data source](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
        to trigger an image update.
        """
        return pulumi.get(self, "pull_triggers")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .container import *
from .docker import *
from .get_network import *
from .get_plugin import *
from .get_registry_image import *
from .image import *
from .network import *
from .plugin import *
from .provider import *
from .registry_image import *
from .remote_image import *
from .secret import *
from .service import *
from .service_config import *
from .utils import *
from .volume import *
from ._inputs import *
from . import outputs

# Make subpackages available:
from . import (
    config,
)

def _register_module():
    import pulumi
    from . import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "docker:index/container:Container":
                return Container(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/network:Network":
                return Network(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/plugin:Plugin":
                return Plugin(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/registryImage:RegistryImage":
                return RegistryImage(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/remoteImage:RemoteImage":
                return RemoteImage(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/secret:Secret":
                return Secret(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/service:Service":
                return Service(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/serviceConfig:ServiceConfig":
                return ServiceConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "docker:index/volume:Volume":
                return Volume(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("docker", "index/container", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/network", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/plugin", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/registryImage", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/remoteImage", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/secret", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/service", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/serviceConfig", _module_instance)
    pulumi.runtime.register_resource_module("docker", "index/volume", _module_instance)


    class Package(pulumi.runtime.ResourcePackage):
        _version = _utilities.get_semver_version()

        def version(self):
            return Package._version

        def construct_provider(self, name: str, typ: str, urn: str) -> pulumi.ProviderResource:
            if typ != "pulumi:providers:docker":
                raise Exception(f"unknown provider type {typ}")
            return Provider(name, pulumi.ResourceOptions(urn=urn))


    pulumi.runtime.register_resource_package("docker", Package())

_register_module()



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Plugin']


class Plugin(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[str]] = None,
                 enable_timeout: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_destroy: Optional[pulumi.Input[bool]] = None,
                 force_disable: Optional[pulumi.Input[bool]] = None,
                 grant_all_permissions: Optional[pulumi.Input[bool]] = None,
                 grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Manages the lifecycle of a Docker plugin.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        sample_volume_plugin = docker.Plugin("sample-volume-plugin")
        ```

        ```python
        import pulumi
        import pulumi_docker as docker

        sample_volume_plugin = docker.Plugin("sample-volume-plugin",
            alias="sample-volume-plugin",
            enable_timeout=60,
            enabled=False,
            envs=["DEBUG=1"],
            force_destroy=True,
            force_disable=True,
            grant_all_permissions=True)
        ```

        ## Import

        Docker plugins can be imported using the long id, e.g. for a plugin `tiborvass/sample-volume-plugin:latest`

        ```sh
         $ pulumi import docker:index/plugin:Plugin sample-volume-plugin $(docker plugin inspect -f "{{.ID}}" tiborvass/sample-volume-plugin:latest)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: The alias of the Docker plugin. If the tag is omitted, `:latest` is complemented to the attribute value.
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin.
        :param pulumi.Input[bool] enabled: If true, the plugin is enabled. The default value is `true`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: . The environment variables.
        :param pulumi.Input[bool] force_destroy: If true, the plugin is removed forcibly when the plugin is removed.
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly when the plugin is disabled.
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin. This attribute conflicts with `grant_permissions`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]] grant_permissions: grant permissions necessary to run the plugin. This attribute conflicts with `grant_all_permissions`. See grant_permissions below for details.
        :param pulumi.Input[str] name: Docker Plugin name
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['alias'] = alias
            __props__['enable_timeout'] = enable_timeout
            __props__['enabled'] = enabled
            __props__['envs'] = envs
            __props__['force_destroy'] = force_destroy
            __props__['force_disable'] = force_disable
            __props__['grant_all_permissions'] = grant_all_permissions
            __props__['grant_permissions'] = grant_permissions
            __props__['name'] = name
            __props__['plugin_reference'] = None
        super(Plugin, __self__).__init__(
            'docker:index/plugin:Plugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias: Optional[pulumi.Input[str]] = None,
            enable_timeout: Optional[pulumi.Input[int]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            force_destroy: Optional[pulumi.Input[bool]] = None,
            force_disable: Optional[pulumi.Input[bool]] = None,
            grant_all_permissions: Optional[pulumi.Input[bool]] = None,
            grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            plugin_reference: Optional[pulumi.Input[str]] = None) -> 'Plugin':
        """
        Get an existing Plugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: The alias of the Docker plugin. If the tag is omitted, `:latest` is complemented to the attribute value.
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin.
        :param pulumi.Input[bool] enabled: If true, the plugin is enabled. The default value is `true`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: . The environment variables.
        :param pulumi.Input[bool] force_destroy: If true, the plugin is removed forcibly when the plugin is removed.
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly when the plugin is disabled.
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin. This attribute conflicts with `grant_permissions`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]] grant_permissions: grant permissions necessary to run the plugin. This attribute conflicts with `grant_all_permissions`. See grant_permissions below for details.
        :param pulumi.Input[str] name: Docker Plugin name
        :param pulumi.Input[str] plugin_reference: (string) The plugin reference.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["alias"] = alias
        __props__["enable_timeout"] = enable_timeout
        __props__["enabled"] = enabled
        __props__["envs"] = envs
        __props__["force_destroy"] = force_destroy
        __props__["force_disable"] = force_disable
        __props__["grant_all_permissions"] = grant_all_permissions
        __props__["grant_permissions"] = grant_permissions
        __props__["name"] = name
        __props__["plugin_reference"] = plugin_reference
        return Plugin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def alias(self) -> pulumi.Output[str]:
        """
        The alias of the Docker plugin. If the tag is omitted, `:latest` is complemented to the attribute value.
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="enableTimeout")
    def enable_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        HTTP client timeout to enable the plugin.
        """
        return pulumi.get(self, "enable_timeout")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, the plugin is enabled. The default value is `true`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def envs(self) -> pulumi.Output[Sequence[str]]:
        """
        . The environment variables.
        """
        return pulumi.get(self, "envs")

    @property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, the plugin is removed forcibly when the plugin is removed.
        """
        return pulumi.get(self, "force_destroy")

    @property
    @pulumi.getter(name="forceDisable")
    def force_disable(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the plugin is disabled forcibly when the plugin is disabled.
        """
        return pulumi.get(self, "force_disable")

    @property
    @pulumi.getter(name="grantAllPermissions")
    def grant_all_permissions(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, grant all permissions necessary to run the plugin. This attribute conflicts with `grant_permissions`.
        """
        return pulumi.get(self, "grant_all_permissions")

    @property
    @pulumi.getter(name="grantPermissions")
    def grant_permissions(self) -> pulumi.Output[Optional[Sequence['outputs.PluginGrantPermission']]]:
        """
        grant permissions necessary to run the plugin. This attribute conflicts with `grant_all_permissions`. See grant_permissions below for details.
        """
        return pulumi.get(self, "grant_permissions")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Docker Plugin name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="pluginReference")
    def plugin_reference(self) -> pulumi.Output[str]:
        """
        (string) The plugin reference.
        """
        return pulumi.get(self, "plugin_reference")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Container']


class Container(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attach: Optional[pulumi.Input[bool]] = None,
                 capabilities: Optional[pulumi.Input[pulumi.InputType['ContainerCapabilitiesArgs']]] = None,
                 command: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cpu_set: Optional[pulumi.Input[str]] = None,
                 cpu_shares: Optional[pulumi.Input[int]] = None,
                 destroy_grace_seconds: Optional[pulumi.Input[int]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerDeviceArgs']]]]] = None,
                 dns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_opts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domainname: Optional[pulumi.Input[str]] = None,
                 entrypoints: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 group_adds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 healthcheck: Optional[pulumi.Input[pulumi.InputType['ContainerHealthcheckArgs']]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 hosts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerHostArgs']]]]] = None,
                 image: Optional[pulumi.Input[str]] = None,
                 init: Optional[pulumi.Input[bool]] = None,
                 ipc_mode: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerLabelArgs']]]]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 log_driver: Optional[pulumi.Input[str]] = None,
                 log_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 logs: Optional[pulumi.Input[bool]] = None,
                 max_retry_count: Optional[pulumi.Input[int]] = None,
                 memory: Optional[pulumi.Input[int]] = None,
                 memory_swap: Optional[pulumi.Input[int]] = None,
                 mounts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerMountArgs']]]]] = None,
                 must_run: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 network_mode: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 networks_advanced: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworksAdvancedArgs']]]]] = None,
                 pid_mode: Optional[pulumi.Input[str]] = None,
                 ports: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerPortArgs']]]]] = None,
                 privileged: Optional[pulumi.Input[bool]] = None,
                 publish_all_ports: Optional[pulumi.Input[bool]] = None,
                 read_only: Optional[pulumi.Input[bool]] = None,
                 remove_volumes: Optional[pulumi.Input[bool]] = None,
                 restart: Optional[pulumi.Input[str]] = None,
                 rm: Optional[pulumi.Input[bool]] = None,
                 security_opts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 shm_size: Optional[pulumi.Input[int]] = None,
                 start: Optional[pulumi.Input[bool]] = None,
                 stdin_open: Optional[pulumi.Input[bool]] = None,
                 sysctls: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 tmpfs: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 tty: Optional[pulumi.Input[bool]] = None,
                 ulimits: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUlimitArgs']]]]] = None,
                 uploads: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUploadArgs']]]]] = None,
                 user: Optional[pulumi.Input[str]] = None,
                 userns_mode: Optional[pulumi.Input[str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerVolumeArgs']]]]] = None,
                 working_dir: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Manages the lifecycle of a Docker container.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        # Find the latest Ubuntu precise image.
        ubuntu_remote_image = docker.RemoteImage("ubuntuRemoteImage", name="ubuntu:precise")
        # Start a container
        ubuntu_container = docker.Container("ubuntuContainer", image=ubuntu_remote_image.latest)
        ```

        ## Import

        Docker containers can be imported using the long id, e.g. for a container named `foo`

        ```sh
         $ pulumi import docker:index/container:Container foo $(docker inspect -f {{.ID}} foo)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] attach: If true attach to the container after its creation and waits the end of his execution.
        :param pulumi.Input[pulumi.InputType['ContainerCapabilitiesArgs']] capabilities: See Capabilities below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command: The command to use to start the
               container. For example, to run `/usr/bin/myprogram -f baz.conf` set the
               command to be `["/usr/bin/myprogram", "-f", "baz.conf"]`.
        :param pulumi.Input[str] cpu_set: A comma-separated list or hyphen-separated range of CPUs a container can use, e.g. `0-1`.
        :param pulumi.Input[int] cpu_shares: CPU shares (relative weight) for the container.
        :param pulumi.Input[int] destroy_grace_seconds: If defined will attempt to stop the container before destroying. Container will be destroyed after `n` seconds or on successful stop.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerDeviceArgs']]]] devices: See Devices below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns: Set of DNS servers.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_opts: Set of DNS options used by the DNS provider(s), see `resolv.conf` documentation for valid list of options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_searches: Set of DNS search domains that are used when bare unqualified hostnames are used inside of the container.
        :param pulumi.Input[str] domainname: Domain name of the container.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] entrypoints: The command to use as the
               Entrypoint for the container. The Entrypoint allows you to configure a
               container to run as an executable. For example, to run `/usr/bin/myprogram`
               when starting a container, set the entrypoint to be
               `["/usr/bin/myprogram"]`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: Environment variables to set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] group_adds: Add additional groups to run as.
        :param pulumi.Input[pulumi.InputType['ContainerHealthcheckArgs']] healthcheck: See Healthcheck below for details.
        :param pulumi.Input[str] hostname: Hostname of the container.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerHostArgs']]]] hosts: Hostname to add.
        :param pulumi.Input[str] image: The ID of the image to back this container.
               The easiest way to get this value is to use the `RemoteImage` resource
               as is shown in the example above.
        :param pulumi.Input[bool] init: Configured whether an init process should be injected for this container. If unset this will default to the `dockerd` defaults.
        :param pulumi.Input[str] ipc_mode: IPC sharing mode for the container. Possible values are: `none`, `private`, `shareable`, `container:<name|id>` or `host`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerLabelArgs']]]] labels: Adding labels.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] links: Set of links for link based
               connectivity between containers that are running on the same host.
        :param pulumi.Input[str] log_driver: The logging driver to use for the container.
               Defaults to "json-file".
        :param pulumi.Input[Mapping[str, Any]] log_opts: Key/value pairs to use as options for
               the logging driver.
        :param pulumi.Input[bool] logs: Save the container logs (`attach` must be enabled).
        :param pulumi.Input[int] max_retry_count: The maximum amount of times to an attempt
               a restart when `restart` is set to "on-failure"
        :param pulumi.Input[int] memory: The memory limit for the container in MBs.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerMountArgs']]]] mounts: See Mounts below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_aliases: Network aliases of the container for user-defined networks only. *Deprecated:* use `networks_advanced` instead.
        :param pulumi.Input[str] network_mode: Network mode of the container.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] networks: Id of the networks in which the
               container is. *Deprecated:* use `networks_advanced` instead.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworksAdvancedArgs']]]] networks_advanced: See Networks Advanced below for details. If this block has priority to the deprecated `network_alias` and `network` properties.
        :param pulumi.Input[str] pid_mode: The PID (Process) Namespace mode for the container. Either `container:<name|id>` or `host`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerPortArgs']]]] ports: See Ports below for details.
        :param pulumi.Input[bool] privileged: Run container in privileged mode.
        :param pulumi.Input[bool] publish_all_ports: Publish all ports of the container.
        :param pulumi.Input[bool] read_only: If true, this volume will be readonly.
               Defaults to false.
        :param pulumi.Input[str] restart: The restart policy for the container. Must be
               one of "no", "on-failure", "always", "unless-stopped".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_opts: Set of string values to customize labels for MLS systems, such as SELinux. See https://docs.docker.com/engine/reference/run/#security-configuration.
        :param pulumi.Input[int] shm_size: Size of `/dev/shm` in MBs.
        :param pulumi.Input[bool] start: If true, then the Docker container will be
               started after creation. If false, then the container is only created.
        :param pulumi.Input[bool] stdin_open: if true, keep STDIN open even if not attached (docker run -i)
        :param pulumi.Input[Mapping[str, Any]] sysctls: A map of kernel parameters (sysctls) to set in the container.
        :param pulumi.Input[Mapping[str, Any]] tmpfs: A map of container directories which should be replaced by `tmpfs mounts`, and their corresponding mount options.
        :param pulumi.Input[bool] tty: if true, allocate a pseudo-tty (docker run -t)
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUlimitArgs']]]] ulimits: See Ulimits below for
               details.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUploadArgs']]]] uploads: See File Upload below for details.
        :param pulumi.Input[str] user: User used for run the first process. Format is
               `user` or `user:group` which user and group can be passed literraly or
               by name.
        :param pulumi.Input[str] userns_mode: Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerVolumeArgs']]]] volumes: See Volumes below for details.
        :param pulumi.Input[str] working_dir: The working directory for commands to run in
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['attach'] = attach
            __props__['capabilities'] = capabilities
            __props__['command'] = command
            __props__['cpu_set'] = cpu_set
            __props__['cpu_shares'] = cpu_shares
            __props__['destroy_grace_seconds'] = destroy_grace_seconds
            __props__['devices'] = devices
            __props__['dns'] = dns
            __props__['dns_opts'] = dns_opts
            __props__['dns_searches'] = dns_searches
            __props__['domainname'] = domainname
            __props__['entrypoints'] = entrypoints
            __props__['envs'] = envs
            __props__['group_adds'] = group_adds
            __props__['healthcheck'] = healthcheck
            __props__['hostname'] = hostname
            __props__['hosts'] = hosts
            if image is None and not opts.urn:
                raise TypeError("Missing required property 'image'")
            __props__['image'] = image
            __props__['init'] = init
            __props__['ipc_mode'] = ipc_mode
            __props__['labels'] = labels
            if links is not None and not opts.urn:
                warnings.warn("""The --link flag is a legacy feature of Docker. It may eventually be removed.""", DeprecationWarning)
                pulumi.log.warn("links is deprecated: The --link flag is a legacy feature of Docker. It may eventually be removed.")
            __props__['links'] = links
            __props__['log_driver'] = log_driver
            __props__['log_opts'] = log_opts
            __props__['logs'] = logs
            __props__['max_retry_count'] = max_retry_count
            __props__['memory'] = memory
            __props__['memory_swap'] = memory_swap
            __props__['mounts'] = mounts
            __props__['must_run'] = must_run
            __props__['name'] = name
            if network_aliases is not None and not opts.urn:
                warnings.warn("""Use networks_advanced instead. Will be removed in v2.0.0""", DeprecationWarning)
                pulumi.log.warn("network_aliases is deprecated: Use networks_advanced instead. Will be removed in v2.0.0")
            __props__['network_aliases'] = network_aliases
            __props__['network_mode'] = network_mode
            if networks is not None and not opts.urn:
                warnings.warn("""Use networks_advanced instead. Will be removed in v2.0.0""", DeprecationWarning)
                pulumi.log.warn("networks is deprecated: Use networks_advanced instead. Will be removed in v2.0.0")
            __props__['networks'] = networks
            __props__['networks_advanced'] = networks_advanced
            __props__['pid_mode'] = pid_mode
            __props__['ports'] = ports
            __props__['privileged'] = privileged
            __props__['publish_all_ports'] = publish_all_ports
            __props__['read_only'] = read_only
            __props__['remove_volumes'] = remove_volumes
            __props__['restart'] = restart
            __props__['rm'] = rm
            __props__['security_opts'] = security_opts
            __props__['shm_size'] = shm_size
            __props__['start'] = start
            __props__['stdin_open'] = stdin_open
            __props__['sysctls'] = sysctls
            __props__['tmpfs'] = tmpfs
            __props__['tty'] = tty
            __props__['ulimits'] = ulimits
            __props__['uploads'] = uploads
            __props__['user'] = user
            __props__['userns_mode'] = userns_mode
            __props__['volumes'] = volumes
            __props__['working_dir'] = working_dir
            __props__['bridge'] = None
            __props__['container_logs'] = None
            __props__['exit_code'] = None
            __props__['gateway'] = None
            __props__['ip_address'] = None
            __props__['ip_prefix_length'] = None
            __props__['network_datas'] = None
        super(Container, __self__).__init__(
            'docker:index/container:Container',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attach: Optional[pulumi.Input[bool]] = None,
            bridge: Optional[pulumi.Input[str]] = None,
            capabilities: Optional[pulumi.Input[pulumi.InputType['ContainerCapabilitiesArgs']]] = None,
            command: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            container_logs: Optional[pulumi.Input[str]] = None,
            cpu_set: Optional[pulumi.Input[str]] = None,
            cpu_shares: Optional[pulumi.Input[int]] = None,
            destroy_grace_seconds: Optional[pulumi.Input[int]] = None,
            devices: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerDeviceArgs']]]]] = None,
            dns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dns_opts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            domainname: Optional[pulumi.Input[str]] = None,
            entrypoints: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            exit_code: Optional[pulumi.Input[int]] = None,
            gateway: Optional[pulumi.Input[str]] = None,
            group_adds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            healthcheck: Optional[pulumi.Input[pulumi.InputType['ContainerHealthcheckArgs']]] = None,
            hostname: Optional[pulumi.Input[str]] = None,
            hosts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerHostArgs']]]]] = None,
            image: Optional[pulumi.Input[str]] = None,
            init: Optional[pulumi.Input[bool]] = None,
            ip_address: Optional[pulumi.Input[str]] = None,
            ip_prefix_length: Optional[pulumi.Input[int]] = None,
            ipc_mode: Optional[pulumi.Input[str]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerLabelArgs']]]]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            log_driver: Optional[pulumi.Input[str]] = None,
            log_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            logs: Optional[pulumi.Input[bool]] = None,
            max_retry_count: Optional[pulumi.Input[int]] = None,
            memory: Optional[pulumi.Input[int]] = None,
            memory_swap: Optional[pulumi.Input[int]] = None,
            mounts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerMountArgs']]]]] = None,
            must_run: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            network_datas: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworkDataArgs']]]]] = None,
            network_mode: Optional[pulumi.Input[str]] = None,
            networks: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            networks_advanced: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworksAdvancedArgs']]]]] = None,
            pid_mode: Optional[pulumi.Input[str]] = None,
            ports: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerPortArgs']]]]] = None,
            privileged: Optional[pulumi.Input[bool]] = None,
            publish_all_ports: Optional[pulumi.Input[bool]] = None,
            read_only: Optional[pulumi.Input[bool]] = None,
            remove_volumes: Optional[pulumi.Input[bool]] = None,
            restart: Optional[pulumi.Input[str]] = None,
            rm: Optional[pulumi.Input[bool]] = None,
            security_opts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            shm_size: Optional[pulumi.Input[int]] = None,
            start: Optional[pulumi.Input[bool]] = None,
            stdin_open: Optional[pulumi.Input[bool]] = None,
            sysctls: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            tmpfs: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            tty: Optional[pulumi.Input[bool]] = None,
            ulimits: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUlimitArgs']]]]] = None,
            uploads: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUploadArgs']]]]] = None,
            user: Optional[pulumi.Input[str]] = None,
            userns_mode: Optional[pulumi.Input[str]] = None,
            volumes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerVolumeArgs']]]]] = None,
            working_dir: Optional[pulumi.Input[str]] = None) -> 'Container':
        """
        Get an existing Container resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] attach: If true attach to the container after its creation and waits the end of his execution.
        :param pulumi.Input[str] bridge: The network bridge of the container as read from its NetworkSettings.
        :param pulumi.Input[pulumi.InputType['ContainerCapabilitiesArgs']] capabilities: See Capabilities below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command: The command to use to start the
               container. For example, to run `/usr/bin/myprogram -f baz.conf` set the
               command to be `["/usr/bin/myprogram", "-f", "baz.conf"]`.
        :param pulumi.Input[str] container_logs: The logs of the container if its execution is done (`attach` must be disabled).
        :param pulumi.Input[str] cpu_set: A comma-separated list or hyphen-separated range of CPUs a container can use, e.g. `0-1`.
        :param pulumi.Input[int] cpu_shares: CPU shares (relative weight) for the container.
        :param pulumi.Input[int] destroy_grace_seconds: If defined will attempt to stop the container before destroying. Container will be destroyed after `n` seconds or on successful stop.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerDeviceArgs']]]] devices: See Devices below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns: Set of DNS servers.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_opts: Set of DNS options used by the DNS provider(s), see `resolv.conf` documentation for valid list of options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_searches: Set of DNS search domains that are used when bare unqualified hostnames are used inside of the container.
        :param pulumi.Input[str] domainname: Domain name of the container.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] entrypoints: The command to use as the
               Entrypoint for the container. The Entrypoint allows you to configure a
               container to run as an executable. For example, to run `/usr/bin/myprogram`
               when starting a container, set the entrypoint to be
               `["/usr/bin/myprogram"]`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: Environment variables to set.
        :param pulumi.Input[int] exit_code: The exit code of the container if its execution is done (`must_run` must be disabled).
        :param pulumi.Input[str] gateway: *Deprecated:* Use `network_data` instead. The network gateway of the container as read from its
               NetworkSettings.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] group_adds: Add additional groups to run as.
        :param pulumi.Input[pulumi.InputType['ContainerHealthcheckArgs']] healthcheck: See Healthcheck below for details.
        :param pulumi.Input[str] hostname: Hostname of the container.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerHostArgs']]]] hosts: Hostname to add.
        :param pulumi.Input[str] image: The ID of the image to back this container.
               The easiest way to get this value is to use the `RemoteImage` resource
               as is shown in the example above.
        :param pulumi.Input[bool] init: Configured whether an init process should be injected for this container. If unset this will default to the `dockerd` defaults.
        :param pulumi.Input[str] ip_address: *Deprecated:* Use `network_data` instead. The IP address of the container's first network it.
        :param pulumi.Input[int] ip_prefix_length: *Deprecated:* Use `network_data` instead. The IP prefix length of the container as read from its
               NetworkSettings.
        :param pulumi.Input[str] ipc_mode: IPC sharing mode for the container. Possible values are: `none`, `private`, `shareable`, `container:<name|id>` or `host`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerLabelArgs']]]] labels: Adding labels.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] links: Set of links for link based
               connectivity between containers that are running on the same host.
        :param pulumi.Input[str] log_driver: The logging driver to use for the container.
               Defaults to "json-file".
        :param pulumi.Input[Mapping[str, Any]] log_opts: Key/value pairs to use as options for
               the logging driver.
        :param pulumi.Input[bool] logs: Save the container logs (`attach` must be enabled).
        :param pulumi.Input[int] max_retry_count: The maximum amount of times to an attempt
               a restart when `restart` is set to "on-failure"
        :param pulumi.Input[int] memory: The memory limit for the container in MBs.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerMountArgs']]]] mounts: See Mounts below for details.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_aliases: Network aliases of the container for user-defined networks only. *Deprecated:* use `networks_advanced` instead.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworkDataArgs']]]] network_datas: (Map of a block) The IP addresses of the container on each
               network. Key are the network names, values are the IP addresses.
        :param pulumi.Input[str] network_mode: Network mode of the container.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] networks: Id of the networks in which the
               container is. *Deprecated:* use `networks_advanced` instead.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerNetworksAdvancedArgs']]]] networks_advanced: See Networks Advanced below for details. If this block has priority to the deprecated `network_alias` and `network` properties.
        :param pulumi.Input[str] pid_mode: The PID (Process) Namespace mode for the container. Either `container:<name|id>` or `host`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerPortArgs']]]] ports: See Ports below for details.
        :param pulumi.Input[bool] privileged: Run container in privileged mode.
        :param pulumi.Input[bool] publish_all_ports: Publish all ports of the container.
        :param pulumi.Input[bool] read_only: If true, this volume will be readonly.
               Defaults to false.
        :param pulumi.Input[str] restart: The restart policy for the container. Must be
               one of "no", "on-failure", "always", "unless-stopped".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_opts: Set of string values to customize labels for MLS systems, such as SELinux. See https://docs.docker.com/engine/reference/run/#security-configuration.
        :param pulumi.Input[int] shm_size: Size of `/dev/shm` in MBs.
        :param pulumi.Input[bool] start: If true, then the Docker container will be
               started after creation. If false, then the container is only created.
        :param pulumi.Input[bool] stdin_open: if true, keep STDIN open even if not attached (docker run -i)
        :param pulumi.Input[Mapping[str, Any]] sysctls: A map of kernel parameters (sysctls) to set in the container.
        :param pulumi.Input[Mapping[str, Any]] tmpfs: A map of container directories which should be replaced by `tmpfs mounts`, and their corresponding mount options.
        :param pulumi.Input[bool] tty: if true, allocate a pseudo-tty (docker run -t)
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUlimitArgs']]]] ulimits: See Ulimits below for
               details.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerUploadArgs']]]] uploads: See File Upload below for details.
        :param pulumi.Input[str] user: User used for run the first process. Format is
               `user` or `user:group` which user and group can be passed literraly or
               by name.
        :param pulumi.Input[str] userns_mode: Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ContainerVolumeArgs']]]] volumes: See Volumes below for details.
        :param pulumi.Input[str] working_dir: The working directory for commands to run in
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["attach"] = attach
        __props__["bridge"] = bridge
        __props__["capabilities"] = capabilities
        __props__["command"] = command
        __props__["container_logs"] = container_logs
        __props__["cpu_set"] = cpu_set
        __props__["cpu_shares"] = cpu_shares
        __props__["destroy_grace_seconds"] = destroy_grace_seconds
        __props__["devices"] = devices
        __props__["dns"] = dns
        __props__["dns_opts"] = dns_opts
        __props__["dns_searches"] = dns_searches
        __props__["domainname"] = domainname
        __props__["entrypoints"] = entrypoints
        __props__["envs"] = envs
        __props__["exit_code"] = exit_code
        __props__["gateway"] = gateway
        __props__["group_adds"] = group_adds
        __props__["healthcheck"] = healthcheck
        __props__["hostname"] = hostname
        __props__["hosts"] = hosts
        __props__["image"] = image
        __props__["init"] = init
        __props__["ip_address"] = ip_address
        __props__["ip_prefix_length"] = ip_prefix_length
        __props__["ipc_mode"] = ipc_mode
        __props__["labels"] = labels
        __props__["links"] = links
        __props__["log_driver"] = log_driver
        __props__["log_opts"] = log_opts
        __props__["logs"] = logs
        __props__["max_retry_count"] = max_retry_count
        __props__["memory"] = memory
        __props__["memory_swap"] = memory_swap
        __props__["mounts"] = mounts
        __props__["must_run"] = must_run
        __props__["name"] = name
        __props__["network_aliases"] = network_aliases
        __props__["network_datas"] = network_datas
        __props__["network_mode"] = network_mode
        __props__["networks"] = networks
        __props__["networks_advanced"] = networks_advanced
        __props__["pid_mode"] = pid_mode
        __props__["ports"] = ports
        __props__["privileged"] = privileged
        __props__["publish_all_ports"] = publish_all_ports
        __props__["read_only"] = read_only
        __props__["remove_volumes"] = remove_volumes
        __props__["restart"] = restart
        __props__["rm"] = rm
        __props__["security_opts"] = security_opts
        __props__["shm_size"] = shm_size
        __props__["start"] = start
        __props__["stdin_open"] = stdin_open
        __props__["sysctls"] = sysctls
        __props__["tmpfs"] = tmpfs
        __props__["tty"] = tty
        __props__["ulimits"] = ulimits
        __props__["uploads"] = uploads
        __props__["user"] = user
        __props__["userns_mode"] = userns_mode
        __props__["volumes"] = volumes
        __props__["working_dir"] = working_dir
        return Container(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def attach(self) -> pulumi.Output[Optional[bool]]:
        """
        If true attach to the container after its creation and waits the end of his execution.
        """
        return pulumi.get(self, "attach")

    @property
    @pulumi.getter
    def bridge(self) -> pulumi.Output[str]:
        """
        The network bridge of the container as read from its NetworkSettings.
        """
        return pulumi.get(self, "bridge")

    @property
    @pulumi.getter
    def capabilities(self) -> pulumi.Output[Optional['outputs.ContainerCapabilities']]:
        """
        See Capabilities below for details.
        """
        return pulumi.get(self, "capabilities")

    @property
    @pulumi.getter
    def command(self) -> pulumi.Output[Sequence[str]]:
        """
        The command to use to start the
        container. For example, to run `/usr/bin/myprogram -f baz.conf` set the
        command to be `["/usr/bin/myprogram", "-f", "baz.conf"]`.
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter(name="containerLogs")
    def container_logs(self) -> pulumi.Output[str]:
        """
        The logs of the container if its execution is done (`attach` must be disabled).
        """
        return pulumi.get(self, "container_logs")

    @property
    @pulumi.getter(name="cpuSet")
    def cpu_set(self) -> pulumi.Output[Optional[str]]:
        """
        A comma-separated list or hyphen-separated range of CPUs a container can use, e.g. `0-1`.
        """
        return pulumi.get(self, "cpu_set")

    @property
    @pulumi.getter(name="cpuShares")
    def cpu_shares(self) -> pulumi.Output[Optional[int]]:
        """
        CPU shares (relative weight) for the container.
        """
        return pulumi.get(self, "cpu_shares")

    @property
    @pulumi.getter(name="destroyGraceSeconds")
    def destroy_grace_seconds(self) -> pulumi.Output[Optional[int]]:
        """
        If defined will attempt to stop the container before destroying. Container will be destroyed after `n` seconds or on successful stop.
        """
        return pulumi.get(self, "destroy_grace_seconds")

    @property
    @pulumi.getter
    def devices(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerDevice']]]:
        """
        See Devices below for details.
        """
        return pulumi.get(self, "devices")

    @property
    @pulumi.getter
    def dns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Set of DNS servers.
        """
        return pulumi.get(self, "dns")

    @property
    @pulumi.getter(name="dnsOpts")
    def dns_opts(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Set of DNS options used by the DNS provider(s), see `resolv.conf` documentation for valid list of options.
        """
        return pulumi.get(self, "dns_opts")

    @property
    @pulumi.getter(name="dnsSearches")
    def dns_searches(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Set of DNS search domains that are used when bare unqualified hostnames are used inside of the container.
        """
        return pulumi.get(self, "dns_searches")

    @property
    @pulumi.getter
    def domainname(self) -> pulumi.Output[Optional[str]]:
        """
        Domain name of the container.
        """
        return pulumi.get(self, "domainname")

    @property
    @pulumi.getter
    def entrypoints(self) -> pulumi.Output[Sequence[str]]:
        """
        The command to use as the
        Entrypoint for the container. The Entrypoint allows you to configure a
        container to run as an executable. For example, to run `/usr/bin/myprogram`
        when starting a container, set the entrypoint to be
        `["/usr/bin/myprogram"]`.
        """
        return pulumi.get(self, "entrypoints")

    @property
    @pulumi.getter
    def envs(self) -> pulumi.Output[Sequence[str]]:
        """
        Environment variables to set.
        """
        return pulumi.get(self, "envs")

    @property
    @pulumi.getter(name="exitCode")
    def exit_code(self) -> pulumi.Output[int]:
        """
        The exit code of the container if its execution is done (`must_run` must be disabled).
        """
        return pulumi.get(self, "exit_code")

    @property
    @pulumi.getter
    def gateway(self) -> pulumi.Output[str]:
        """
        *Deprecated:* Use `network_data` instead. The network gateway of the container as read from its
        NetworkSettings.
        """
        return pulumi.get(self, "gateway")

    @property
    @pulumi.getter(name="groupAdds")
    def group_adds(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Add additional groups to run as.
        """
        return pulumi.get(self, "group_adds")

    @property
    @pulumi.getter
    def healthcheck(self) -> pulumi.Output['outputs.ContainerHealthcheck']:
        """
        See Healthcheck below for details.
        """
        return pulumi.get(self, "healthcheck")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[str]:
        """
        Hostname of the container.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def hosts(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerHost']]]:
        """
        Hostname to add.
        """
        return pulumi.get(self, "hosts")

    @property
    @pulumi.getter
    def image(self) -> pulumi.Output[str]:
        """
        The ID of the image to back this container.
        The easiest way to get this value is to use the `RemoteImage` resource
        as is shown in the example above.
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter
    def init(self) -> pulumi.Output[bool]:
        """
        Configured whether an init process should be injected for this container. If unset this will default to the `dockerd` defaults.
        """
        return pulumi.get(self, "init")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[str]:
        """
        *Deprecated:* Use `network_data` instead. The IP address of the container's first network it.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipPrefixLength")
    def ip_prefix_length(self) -> pulumi.Output[int]:
        """
        *Deprecated:* Use `network_data` instead. The IP prefix length of the container as read from its
        NetworkSettings.
        """
        return pulumi.get(self, "ip_prefix_length")

    @property
    @pulumi.getter(name="ipcMode")
    def ipc_mode(self) -> pulumi.Output[str]:
        """
        IPC sharing mode for the container. Possible values are: `none`, `private`, `shareable`, `container:<name|id>` or `host`.
        """
        return pulumi.get(self, "ipc_mode")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Sequence['outputs.ContainerLabel']]:
        """
        Adding labels.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Set of links for link based
        connectivity between containers that are running on the same host.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter(name="logDriver")
    def log_driver(self) -> pulumi.Output[Optional[str]]:
        """
        The logging driver to use for the container.
        Defaults to "json-file".
        """
        return pulumi.get(self, "log_driver")

    @property
    @pulumi.getter(name="logOpts")
    def log_opts(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        Key/value pairs to use as options for
        the logging driver.
        """
        return pulumi.get(self, "log_opts")

    @property
    @pulumi.getter
    def logs(self) -> pulumi.Output[Optional[bool]]:
        """
        Save the container logs (`attach` must be enabled).
        """
        return pulumi.get(self, "logs")

    @property
    @pulumi.getter(name="maxRetryCount")
    def max_retry_count(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum amount of times to an attempt
        a restart when `restart` is set to "on-failure"
        """
        return pulumi.get(self, "max_retry_count")

    @property
    @pulumi.getter
    def memory(self) -> pulumi.Output[Optional[int]]:
        """
        The memory limit for the container in MBs.
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="memorySwap")
    def memory_swap(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "memory_swap")

    @property
    @pulumi.getter
    def mounts(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerMount']]]:
        """
        See Mounts below for details.
        """
        return pulumi.get(self, "mounts")

    @property
    @pulumi.getter(name="mustRun")
    def must_run(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "must_run")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkAliases")
    def network_aliases(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Network aliases of the container for user-defined networks only. *Deprecated:* use `networks_advanced` instead.
        """
        return pulumi.get(self, "network_aliases")

    @property
    @pulumi.getter(name="networkDatas")
    def network_datas(self) -> pulumi.Output[Sequence['outputs.ContainerNetworkData']]:
        """
        (Map of a block) The IP addresses of the container on each
        network. Key are the network names, values are the IP addresses.
        """
        return pulumi.get(self, "network_datas")

    @property
    @pulumi.getter(name="networkMode")
    def network_mode(self) -> pulumi.Output[Optional[str]]:
        """
        Network mode of the container.
        """
        return pulumi.get(self, "network_mode")

    @property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Id of the networks in which the
        container is. *Deprecated:* use `networks_advanced` instead.
        """
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="networksAdvanced")
    def networks_advanced(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerNetworksAdvanced']]]:
        """
        See Networks Advanced below for details. If this block has priority to the deprecated `network_alias` and `network` properties.
        """
        return pulumi.get(self, "networks_advanced")

    @property
    @pulumi.getter(name="pidMode")
    def pid_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The PID (Process) Namespace mode for the container. Either `container:<name|id>` or `host`.
        """
        return pulumi.get(self, "pid_mode")

    @property
    @pulumi.getter
    def ports(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerPort']]]:
        """
        See Ports below for details.
        """
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter
    def privileged(self) -> pulumi.Output[Optional[bool]]:
        """
        Run container in privileged mode.
        """
        return pulumi.get(self, "privileged")

    @property
    @pulumi.getter(name="publishAllPorts")
    def publish_all_ports(self) -> pulumi.Output[Optional[bool]]:
        """
        Publish all ports of the container.
        """
        return pulumi.get(self, "publish_all_ports")

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, this volume will be readonly.
        Defaults to false.
        """
        return pulumi.get(self, "read_only")

    @property
    @pulumi.getter(name="removeVolumes")
    def remove_volumes(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "remove_volumes")

    @property
    @pulumi.getter
    def restart(self) -> pulumi.Output[Optional[str]]:
        """
        The restart policy for the container. Must be
        one of "no", "on-failure", "always", "unless-stopped".
        """
        return pulumi.get(self, "restart")

    @property
    @pulumi.getter
    def rm(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "rm")

    @property
    @pulumi.getter(name="securityOpts")
    def security_opts(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of string values to customize labels for MLS systems, such as SELinux. See https://docs.docker.com/engine/reference/run/#security-configuration.
        """
        return pulumi.get(self, "security_opts")

    @property
    @pulumi.getter(name="shmSize")
    def shm_size(self) -> pulumi.Output[int]:
        """
        Size of `/dev/shm` in MBs.
        """
        return pulumi.get(self, "shm_size")

    @property
    @pulumi.getter
    def start(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the Docker container will be
        started after creation. If false, then the container is only created.
        """
        return pulumi.get(self, "start")

    @property
    @pulumi.getter(name="stdinOpen")
    def stdin_open(self) -> pulumi.Output[Optional[bool]]:
        """
        if true, keep STDIN open even if not attached (docker run -i)
        """
        return pulumi.get(self, "stdin_open")

    @property
    @pulumi.getter
    def sysctls(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        A map of kernel parameters (sysctls) to set in the container.
        """
        return pulumi.get(self, "sysctls")

    @property
    @pulumi.getter
    def tmpfs(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        A map of container directories which should be replaced by `tmpfs mounts`, and their corresponding mount options.
        """
        return pulumi.get(self, "tmpfs")

    @property
    @pulumi.getter
    def tty(self) -> pulumi.Output[Optional[bool]]:
        """
        if true, allocate a pseudo-tty (docker run -t)
        """
        return pulumi.get(self, "tty")

    @property
    @pulumi.getter
    def ulimits(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerUlimit']]]:
        """
        See Ulimits below for
        details.
        """
        return pulumi.get(self, "ulimits")

    @property
    @pulumi.getter
    def uploads(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerUpload']]]:
        """
        See File Upload below for details.
        """
        return pulumi.get(self, "uploads")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output[Optional[str]]:
        """
        User used for run the first process. Format is
        `user` or `user:group` which user and group can be passed literraly or
        by name.
        """
        return pulumi.get(self, "user")

    @property
    @pulumi.getter(name="usernsMode")
    def userns_mode(self) -> pulumi.Output[Optional[str]]:
        """
        Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
        """
        return pulumi.get(self, "userns_mode")

    @property
    @pulumi.getter
    def volumes(self) -> pulumi.Output[Optional[Sequence['outputs.ContainerVolume']]]:
        """
        See Volumes below for details.
        """
        return pulumi.get(self, "volumes")

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> pulumi.Output[Optional[str]]:
        """
        The working directory for commands to run in
        """
        return pulumi.get(self, "working_dir")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

